@@ -81,6 +81,7 @@
 (fn-p-to-fn?-alias 'realgud-loc-p)
 
 (defvar realgud-track-divert-string)
+(defvar starting-directory)
 
 (defun realgud-track-comint-output-filter-hook(text)
   "An output-filter hook custom for comint shells.  Find
@@ -206,6 +207,10 @@ evaluating (realgud-cmdbuf-info-loc-regexp realgud-cmdbuf-info)"
 					       (realgud-cmdbuf-pat "brkpt-disable")
 					       nil)
 	      (setq frame-num (realgud-track-selected-frame text))
+	      (if (and frame-num (not loc))
+		  (setq loc (realgud-track-loc-from-selected-frame
+			     text cmd-mark)))
+
 	      (setq bp-loc (realgud-track-bp-loc text-sans-loc cmd-mark cmdbuf))
 	      (if bp-loc
 		  (let ((src-buffer (realgud-loc-goto bp-loc)))
@@ -407,7 +412,11 @@ Otherwise return nil."
 				     (match-string alt-line-group text)))
 		       (source-str (and text-group
 					(match-string text-group text)))
-		       (lineno (string-to-number (or line-str "1"))))
+		       (lineno (string-to-number (or line-str "1")))
+		       (directory
+			(cond ((boundp 'starting-directory) starting-directory)
+				     (t nil)))
+		       )
 		  (when source-str
 		    (setq source-str (ansi-color-filter-apply
 				      source-str)))
@@ -422,7 +431,10 @@ Otherwise return nil."
 			     (realgud:file-loc-from-line filename lineno
 							 cmd-mark
 							 source-str nil
-							 ignore-file-re)
+							 ignore-file-re
+							 nil
+							 directory
+							 )
 			   ;; else
 			   nil)))))
 	  ;; else
@@ -456,6 +468,7 @@ Otherwise return nil. CMD-MARK is set in the realgud-loc object created.
 		    (line-group     (realgud-loc-pat-line-group loc-pat))
 		    (text-group     (realgud-loc-pat-text-group loc-pat))
 		    (ignore-file-re (realgud-loc-pat-ignore-file-re loc-pat))
+		    (callback-loc-fn (realgud-sget 'cmdbuf-info 'callback-loc-fn))
 		    )
 		(if loc-regexp
 		    (if (string-match loc-regexp text)
@@ -465,30 +478,42 @@ Otherwise return nil. CMD-MARK is set in the realgud-loc object created.
 			       (source-str (and text-group (match-string text-group text)))
 			       (lineno (string-to-number (or line-str "1")))
 			       )
-			  (unless line-str
-			    (message "line number not found -- using 1"))
-			  (if (and filename lineno)
-			      (let ((loc-or-error
-				     (realgud:file-loc-from-line
-				      filename lineno
-				      cmd-mark
-				      source-str
-				      (string-to-number bp-num)
-				      ignore-file-re
-				      )))
-				(if (stringp loc-or-error)
-				    (progn
-				      (message loc-or-error)
-				      ;; set to return nil
-				      nil)
-				  ;; else
-				  (progn
-				    ;; Add breakpoint to list of breakpoints
-				    (realgud-cmdbuf-info-bp-list=
-				     (cons loc-or-error (realgud-sget 'cmdbuf-info 'bp-list)))
-				    ;; Set to return location
-				    loc-or-error)))
-			    nil)))
+			  (cond (callback-loc-fn
+				 (funcall callback-loc-fn text
+					  filename lineno source-str
+					  ignore-file-re cmd-mark))
+
+				('t
+				 (unless line-str
+				   (message "line number not found -- using 1"))
+				 (if (and filename lineno)
+				     (let* ((directory
+					     (cond ((boundp 'starting-directory) starting-directory)
+						   (t nil)))
+					    (loc-or-error
+					     (realgud:file-loc-from-line
+					      filename lineno
+					      cmd-mark
+					      source-str
+					      (string-to-number bp-num)
+					      ignore-file-re nil directory
+					      )))
+				       (if (stringp loc-or-error)
+					   (progn
+					     (message loc-or-error)
+					     ;; set to return nil
+					     nil)
+					 ;; else
+					 (let ((loc loc-or-error))
+					   ;; Add breakpoint to list of breakpoints
+					   (with-current-buffer-safe (marker-buffer (realgud-loc-marker loc))
+					     (realgud-bp-add-info loc))
+
+					   (realgud-cmdbuf-info-bp-list=
+					    (cons loc (realgud-sget 'cmdbuf-info 'bp-list)))
+					   ;; Set to return location
+					   loc-or-error))))
+				 nil))))
 		  nil))
             nil))
       )
@@ -600,6 +625,30 @@ loc-regexp pattern"
   )
 
 
+(defun realgud-track-loc-from-selected-frame(text cmd-mark &optional
+						  opt-regexp opt-ignore-file-re)
+  "Return a selected frame number found in TEXT or nil if none found."
+  (if (realgud-cmdbuf?)
+      (let ((selected-frame-pat (realgud-cmdbuf-pat "selected-frame"))
+	    (frame-num-regexp)
+	    (ignore-file-re (or opt-ignore-file-re
+				(realgud-sget 'cmdbuf-info 'ignore-file-re))))
+	(if (and selected-frame-pat
+		 (setq frame-num-regexp (realgud-loc-pat-regexp
+					 selected-frame-pat)))
+	    (if (string-match frame-num-regexp text)
+		(let* ((file-group (realgud-loc-pat-file-group selected-frame-pat))
+		       (line-group (realgud-loc-pat-line-group selected-frame-pat))
+		       (filename (match-string file-group text))
+		       (lineno (string-to-number (match-string line-group text))))
+		  (if (and filename lineno)
+		      (realgud:file-loc-from-line filename lineno
+						  cmd-mark nil nil ignore-file-re)
+		    nil))
+	      nil)
+	  nil))
+    nil))
+
 (defun realgud-track-termination?(text)
   "Return 't and call `realgud:terminate' we we have a termination message"
   (if (realgud-cmdbuf?)
@@ -762,3 +811,7 @@ command buffer's debugger location pattern against the line at PT."
     ))
 
 (provide-me "realgud-")
+
+;; Local Variables:
+;; byte-compile-warnings: (not cl-functions)
+;; End:
